{
  description = "A simple flake for a nix-shell";

  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-unstable";
    home-manager.url = "github:nix-community/home-manager/master";
    home-manager.inputs.nixpkgs.follows = "nixpkgs";
    catppuccin.url = "github:catppuccin/nix";
    spicetify-nix = {
      url = "github:Gerg-L/spicetify-nix";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    nix-ld.url = "github:Mic92/nix-ld";
    nix-ld.inputs.nixpkgs.follows = "nixpkgs";

    mcmojave-hyprcursor.url = "github:libadoxon/mcmojave-hyprcursor";
  };

  outputs = { self, nixpkgs, ... } @ inputs: let
    lib = nixpkgs.lib;
    system = "x86_64-linux";
    pkgs = nixpkgs.legacyPackages.${system};
    catppuccinFlavor = "macchiato";
  in {
    nixosConfigurations = {
      hp-laptop-lho = lib.nixosSystem {
          inherit system;
          specialArgs = {
            inherit inputs;
            inherit catppuccinFlavor;
          };
          modules = [ 
            inputs.nix-ld.nixosModules.nix-ld
            ./configuration.nix
            inputs.catppuccin.nixosModules.catppuccin
          ];
      };
    };
    homeConfigurations = {
      lorenz = inputs.home-manager.lib.homeManagerConfiguration {
          inherit pkgs;
          extraSpecialArgs = { 
            inherit inputs;
            inherit catppuccinFlavor;
          };
          modules = [ 
            ./home.nix
            inputs.catppuccin.homeManagerModules.catppuccin
          ];
      };
    };
  };
}
